#include "colors.inc"
#include "metals.inc"
#include "golds.inc"                                                            
#include "txttree.inc"

// deux scenes: clock 0-1 / 1-2
// ouverture 0: plongee sur les arbres avec le robot arrivant
// --> 1 : le robot est a mi-chemin de la porte, plan en pied du robot
// 1-->2 vue normal, prise derriere l'epaule du robot
// -->2 le robot est sous l'arche de la porte, plan en pied large
// 
//
// vitesse du robot : dans les 20 km/h <--> 16 a 17 metre/clock (1 clock = 3 s)
// duree prevue a 25 fps, 0->1 : 3s 1->2 : 3s ( 800 k pour cette phase )
//



global_settings { 
max_trace_level 50
 }                                          
//=========================================
// Camera & light
//-----------------------------------------

#switch(clock)
#range(1,2)
#declare PdV=<1, 4.3 , 19+13*(1-(clock-1))>;
#break
#range(0,1)
#declare PdV=<30, 30 , -20>*(1-clock) + (<1,5,13+22>*clock);
#break
#end



#switch(clock)
#range(1,2)
#declare PdA=<0.5,4,13+16*(1-(clock-1))>;
#break
#range(0,1)
#declare PdA=<0,2,3+(10+16)*clock+(7*sin(clock*pi))>;
#break
#end

#debug concat("Clock : ",str(clock,1,2),"\n")
#debug concat("PdV : ",str(PdV.x,1,2)," , ",str(PdV.y,1,2)," , ",str(PdV.z,1,2),"\n")
#debug concat("PdA : ",str(PdA.x,1,2)," , ",str(PdA.y,1,2)," , ",str(PdA.z,1,2),"\n")

camera {location  PdV direction <0.0 , 0.0 , 1+clock/3 > up y  right 4*x/3 look_at   PdA}
//-----------------------------------------
light_source{PdV color White*0.5  shadowless}
light_source{<-2000,40000,-5000> color White*1.9}

sky_sphere {
    pigment {
      gradient y
      color_map {
        [ 0.5  color CornflowerBlue ]
        [ 1.0  color MidnightBlue ]
      }
      scale 2
      translate -1
    }
}                       

#declare Sandstone = texture {
  pigment { agate frequency 10 pigment_map {
      [ 0 rgb <.6,.5,.4> ]
      [.1 rgb <.65,.6,.55> ]
      [.9 rgb <.65,.6,.55> ]
      [1  rgb <.7,.6,.5> ]
  }
  //scale <20,1,20>
  }
  normal { granite scale 10 }
}
 
difference {                    
plane{y,0 }
box { <-2,-0.5,-20000>,<2,1,20000> }
 texture { Sandstone} 
}

sphere { <0,0,0>,5150
 texture { Sandstone }
 translate <-1400,-5000,1500>
}

sphere { <0,0,0>,5150
 texture { Sandstone }
 translate <1400,-5000,1500>
}

sphere { <0,0,0>,5150
 texture { Sandstone }
 translate <-1400,-5000,-1500>
}

sphere { <0,0,0>,5150
 texture { Sandstone }
 translate <1400,-5000,-1500>
}

box { <-2,0,-20000>,<2,-0.5,20000>
 pigment{ Gray30}
}
 
#declare txtTree=texture{txtTree_6} // Bark texture                             
#declare txtLeaf=texture{txtLeaf_4} // Leaf texture                             
#declare Leaf    =object{#include "gtleaf.inc" }
#declare Treea   =object{#include "gttreea.inc" }
#declare Foliagea=object{#include "gtfoliagea.inc" texture{txtLeaf} }

#declare Treeb   =object{#include "gttreeb.inc" }
#declare Foliageb=object{#include "gtfoliageb.inc" texture{txtLeaf} }           

#declare Treec   =object{#include "gttreec.inc" }
#declare Foliagec=object{#include "gtfoliagec.inc" texture{txtLeaf} }           

#declare Treed   =object{#include "gttreed.inc" }
#declare Foliaged=object{#include "gtfoliaged.inc" texture{txtLeaf} }           

#declare Treem   =object{#include "gttreem.inc" }
#declare Foliagem=object{#include "gtfoliagem.inc" texture{txtLeaf} }           

#declare Trees   =object{#include "gttrees.inc" }
#declare Foliages=object{#include "gtfoliages.inc" texture{txtLeaf} }           


#declare rayo=9.0;

union {
  object{Treea}
  object{Foliagea}
  scale 1/10
  translate <rayo,0,0>
  // rotate <0,60,0>
}
union {
  object{Treeb}
  object{Foliageb}
  scale 1/10
  translate <rayo,0,0>
  rotate <0,120,0>
}
union {
  object{Treec}
  object{Foliagec}
  scale 1/10
  translate <rayo,0,0>
  rotate <0,-120,0>
}
union {
  object{Treed}
  object{Foliaged}
  scale 1/10
  translate <rayo,0,0>
  rotate <0,60,0>
}
union {
  object{Treem}
  object{Foliagem}
  scale 1/10
  translate <rayo,0,0>
  rotate <0,180,0>
}
union {
  object{Trees}
  object{Foliages}
  scale 1/10
  translate <rayo,0,0>
  rotate <0,-60,0>
}
 
#declare murpig=
 pigment{ brick pigment{White},pigment{Red}
 brick_size <0.4,0.1,0.2>
 mortar 0.03
 }
#declare loop=-200;
#while (loop<200)
#declare murpos=<0,0,13>+loop*<0,0,1000>;
#declare loop=loop+1;
box { <-20000,0,0>,<-2,5,1>
 pigment{murpig}
 translate murpos
}
box { <2,0,0>,<20000,5,1>
 pigment{murpig}
 translate murpos
}

difference { 
cylinder { <0,0,0>,<0,0,1>,3 }
cylinder { <0,0,-1>,<0,0,2>,2 }
plane { y , 0 }
 pigment{murpig
 rotate <90,0,0>
 warp { cylinder <0,0,0>,<1,1,6.11> }
 rotate <90,0,0>
 }
translate <0,5,0>+murpos
}
#end

#declare T_Robot =
   texture { T_Gold_4D
   finish { ambient .1 diffuse .1 specular 1 roughness .01
   reflection .5 brilliance 4 metallic on }
 
}
 
#declare T_Chenille =
   texture { T_Chrome_4D
   finish { ambient .1 diffuse .1 specular 1 roughness .01
   reflection .5 brilliance 4 metallic on }
}                                                                               


#declare TX=0.0; // translation x
#declare TY=0.0; // translation y
#declare TZ=13.0+16*(2-clock); // translation z
 
#declare RY=90.0; //clock*180.0; // orientation chenilles
 
#declare AlphaD=00.0; // rotation droite  0-360
#declare AlphaG=00; // rotation gauche 0-360
#declare Tilt=30.0; // inclinaison du tronc  0-90/180
 
#declare ChenilleD=-1*(13.0+16*(2-clock));// phase de la chenille droite
#declare ChenilleG=-1*(13.0+16*(2-clock));// phase de la chenille gauche                      

#include "robot.inc"
